//---------------------------------------------------------------------------
#ifndef biblecsmgrH
#define biblecsmgrH
#include <swmgr.h>
#include "ModInstForm.h"
//---------------------------------------------------------------------------

enum PlatformIDs { WIN32S = 0, WIN9X, WINNT, WINCE };

class BibleCSMGR : public SWMgr {
	TModInstFrm *ModInstFrm;
//	SWFilter *arshaping;
	SWFilter *bidireorder;
        SWFilter *transliterator;
        char platformID;

protected:
	virtual char AddModToConfig(int conffd, const char *fname);
	virtual void AddRenderFilters(SWModule *module, ConfigEntMap &section);
        virtual signed char Load ();
        virtual void AddGlobalOptions (SWModule * module, ConfigEntMap & section,
                                        ConfigEntMap::iterator start,
                                        ConfigEntMap::iterator end);

public:
	BibleCSMGR(TModInstFrm *iModInstFrm);
	virtual ~BibleCSMGR();
};

#endif
 
